-- module_dock_hanger_crib_triggers.lua: Dock and Hanger Crib Triggers [nclok1405]

-- Dock Location
DHCT_DOCK_X = 431.295288085938
DHCT_DOCK_Y = 8.0703125
DHCT_DOCK_Z = 936.460083007812

-- Hanger Location
DHCT_HANGER_X = -1425.1513671875
DHCT_HANGER_Y = 18.078125
DHCT_HANGER_Z = -1209.81579589844

-- Main Thread
-- Run it by `thread_new("dhct_main_thread")` from sr3_city_main()
function dhct_main_thread()
	fade_in_block()	-- Wait until the loading screen goes away
	
	local dock_marker_visible = false
	local dock_prompt_visible = false
	local hanger_marker_visible = false
	local hanger_prompt_visible = false
	
	while true do
		thread_yield()
		
		if mission_is_active() then
			-- If a mission becomes active, disable everything and wait until the mission ends
			if dock_marker_visible then
				marker_remove("Dock_Purchase", SYNC_LOCAL)
				dock_marker_visible = false
			end
			if dock_prompt_visible then
				hud_prompt_clear()
				dock_prompt_visible = false
			end
			if hanger_marker_visible then
				marker_remove("Plane_Hanger", SYNC_LOCAL)
				hanger_marker_visible = false
			end
			if hanger_prompt_visible then
				hud_prompt_clear()
				hanger_prompt_visible = false
			end
			
			while mission_is_active() do
				thread_yield()
			end
		end
		
		-- Dock
		if dhct_sriv() or crib_is_unlocked("Dock_Purchase") then
			if not dhct_sriv() then
				if (not dock_marker_visible) and dhct_is_close_enough(DHCT_DOCK_X, DHCT_DOCK_Y, DHCT_DOCK_Z, 30) then
					marker_add("Dock_Purchase", MINIMAP_ICON_USE, OI_ASSET_USE, OI_FLAGS_FULL, SYNC_LOCAL)
					dock_marker_visible = true
				elseif dock_marker_visible and (not dhct_is_close_enough(DHCT_DOCK_X, DHCT_DOCK_Y, DHCT_DOCK_Z, 30)) then
					marker_remove("Dock_Purchase", SYNC_LOCAL)
					dock_marker_visible = false
				end
			end
			
			if (not dock_prompt_visible) and (not character_is_in_vehicle(LOCAL_PLAYER)) and dhct_is_close_enough(DHCT_DOCK_X, DHCT_DOCK_Y, DHCT_DOCK_Z, 5) then
				hud_prompt(LOCAL_PLAYER, "HUD_USE_CRIB", "dhct_trigger_crib")
				dock_prompt_visible = true
			elseif dock_prompt_visible and (character_is_in_vehicle(LOCAL_PLAYER) or (not dhct_is_close_enough(DHCT_DOCK_X, DHCT_DOCK_Y, DHCT_DOCK_Z, 5))) then
				hud_prompt_clear()
				dock_prompt_visible = false
			end
		end
		
		-- Hanger
		if dhct_sriv() or crib_is_unlocked("Plane_Hanger") then
			if not dhct_sriv() then
				if (not hanger_marker_visible) and dhct_is_close_enough(DHCT_HANGER_X, DHCT_HANGER_Y, DHCT_HANGER_Z, 30) then
					marker_add("Plane_Hanger", MINIMAP_ICON_USE, OI_ASSET_USE, OI_FLAGS_FULL, SYNC_LOCAL)
					hanger_marker_visible = true
				elseif hanger_marker_visible and (not dhct_is_close_enough(DHCT_HANGER_X, DHCT_HANGER_Y, DHCT_HANGER_Z, 30)) then
					marker_remove("Plane_Hanger", SYNC_LOCAL)
					hanger_marker_visible = false
				end
			end
			
			if (not hanger_prompt_visible) and (not character_is_in_vehicle(LOCAL_PLAYER)) and dhct_is_close_enough(DHCT_HANGER_X, DHCT_HANGER_Y, DHCT_HANGER_Z, 5) then
				hud_prompt(LOCAL_PLAYER, "HUD_USE_CRIB", "dhct_trigger_crib")
				hanger_prompt_visible = true
			elseif hanger_prompt_visible and (character_is_in_vehicle(LOCAL_PLAYER) or (not dhct_is_close_enough(DHCT_HANGER_X, DHCT_HANGER_Y, DHCT_HANGER_Z, 5))) then
				hud_prompt_clear()
				hanger_prompt_visible = false
			end
		end
	end
end

-- Check if player's position is close enough to the specified location
function dhct_is_close_enough(ox, oy, oz, dist)
	local px, py, pz = get_object_pos(LOCAL_PLAYER)
	
	local dx = px - ox
	local dy = py - oy
	local dz = pz - oz
	
	if dx < 0 then
		dx = -dx
	end
	if dy < 0 then
		dy = -dy
	end
	if dz < 0 then
		dz = -dz
	end
	
	if (dx < dist) and (dy < dist) and (dz < dist) then
		return true
	end
	return false
end

-- Trigger the Crib Menu
function dhct_trigger_crib()
	hud_push_screen("store_common", SYNC_LOCAL)
	hud_push_screen("store_crib", SYNC_LOCAL)
end

-- Returns true if the game is SRIV and false on SRTT
function dhct_sriv()
	if MAX_NOTORIETY_LEVEL == 6 then
		return true
	end
	return false
end
